==> igniteui-webcomponents-core-4.0.2.tgz: package/esm2015/lib/ApplyButtonClickEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ApplyButtonClickEventArgsDescription } from "./ApplyButtonClickEventArgsDescription";
/**
 * @hidden
 */
export let ApplyButtonClickEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ApplyButtonClickEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ApplyButtonClickEventArgsDescriptionMetadata.a == null) {
                ApplyButtonClickEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ApplyButtonClickEventArgsDescriptionMetadata.c(ApplyButtonClickEventArgsDescriptionMetadata.a);
            }
            if (a.j(ApplyButtonClickEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.y(ApplyButtonClickEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ApplyButtonClickEventArgsDescriptionMetadata.b(a);
            a.aa("ApplyButtonClickEventArgs", () => new ApplyButtonClickEventArgsDescription());
            a.z("ApplyButtonClickEventArgs", ApplyButtonClickEventArgsDescriptionMetadata.a);
        }
    }
    ApplyButtonClickEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ApplyButtonClickEventArgsDescriptionMetadata, 'ApplyButtonClickEventArgsDescriptionMetadata');
    ApplyButtonClickEventArgsDescriptionMetadata.a = null;
    return ApplyButtonClickEventArgsDescriptionMetadata;
})();

==> igniteui-webcomponents-core-4.2.5.tgz: package/esm2015/lib/ApplyButtonClickEventArgsDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { ApplyButtonClickEventArgsDescription } from "./ApplyButtonClickEventArgsDescription";
/**
 * @hidden
 */
export let ApplyButtonClickEventArgsDescriptionMetadata = /*@__PURE__*/ (() => {
    class ApplyButtonClickEventArgsDescriptionMetadata extends Base {
        static b(a) {
            if (ApplyButtonClickEventArgsDescriptionMetadata.a == null) {
                ApplyButtonClickEventArgsDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
                ApplyButtonClickEventArgsDescriptionMetadata.c(ApplyButtonClickEventArgsDescriptionMetadata.a);
            }
            if (a.k(ApplyButtonClickEventArgsDescriptionMetadata.a)) {
                return;
            }
            a.aa(ApplyButtonClickEventArgsDescriptionMetadata.a);
        }
        static c(a) {
        }
        static d(a) {
            ApplyButtonClickEventArgsDescriptionMetadata.b(a);
            a.ac("ApplyButtonClickEventArgs", () => new ApplyButtonClickEventArgsDescription());
            a.ab("ApplyButtonClickEventArgs", ApplyButtonClickEventArgsDescriptionMetadata.a);
        }
    }
    ApplyButtonClickEventArgsDescriptionMetadata.$t = /*@__PURE__*/ markType(ApplyButtonClickEventArgsDescriptionMetadata, 'ApplyButtonClickEventArgsDescriptionMetadata');
    ApplyButtonClickEventArgsDescriptionMetadata.a = null;
    return ApplyButtonClickEventArgsDescriptionMetadata;
})();
